<?php
// File: private_chat.php

session_start();

// Ensure user is logged in and chat partner is set
if (!isset($_SESSION['username'])) {
    header('Location: user_login.php');
    exit;
}

$username = $_SESSION['username'];
$chat_with = isset($_SESSION['chat_with']) ? $_SESSION['chat_with'] : '';

// Get the list of available chat partners
$users_file = 'users.txt';
$available_users = file_exists($users_file) ? file($users_file, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES) : [];
$available_users = array_filter($available_users, fn($user) => $user !== $username);

// Change chat partner if requested
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['chat_with'])) {
    $chat_with = $_POST['chat_with'];
    $_SESSION['chat_with'] = $chat_with;
}

// Chat log file for the two users
$chat_log_file = $chat_with ? "chats/" . min($username, $chat_with) . "_" . max($username, $chat_with) . ".txt" : '';

// Ensure chat log directory exists
if (!file_exists('chats')) {
    mkdir('chats', 0777, true);
}

// Handle sending a message
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['message']) && $chat_with) {
    $message = trim($_POST['message']);
    if ($message) {
        $formatted_message = date('[H:i]') . " $username: " . htmlspecialchars($message) . "\n";
        file_put_contents($chat_log_file, $formatted_message, FILE_APPEND);
    }
}

?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Chat with <?= htmlspecialchars($chat_with ?: 'Select a user') ?></title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
            background-color: #f3f4f6;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
        }

        .chat-container {
            width: 90%;
            max-width: 600px;
            background: #ffffff;
            border-radius: 10px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            overflow: hidden;
            display: flex;
            flex-direction: column;
        }

        .chat-header {
            background: #4a76a8;
            color: #ffffff;
            padding: 15px;
            font-size: 18px;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .chat-box {
            padding: 15px;
            height: 400px;
            overflow-y: auto;
            background: #f9f9f9;
            flex-grow: 1;
        }

        .chat-box div {
            margin-bottom: 10px;
            padding: 10px;
            border-radius: 5px;
            background: #e9eff6;
        }

        .message-form {
            display: flex;
            border-top: 1px solid #ddd;
            padding: 10px;
            background: #ffffff;
        }

        .message-form input {
            flex: 1;
            padding: 10px;
            border: 1px solid #ccc;
            border-radius: 5px;
            margin-right: 10px;
        }

        .message-form button {
            padding: 10px 20px;
            border: none;
            border-radius: 5px;
            background-color: #4a76a8;
            color: #ffffff;
            cursor: pointer;
        }

        .message-form button:hover {
            background-color: #3c5e8b;
        }

        .chat-select {
            background: #ffffff;
            border: 1px solid #ccc;
            border-radius: 5px;
            padding: 5px;
            font-size: 14px;
        }

        .chat-select-form {
            display: flex;
            align-items: center;
            gap: 10px;
        }

        .logout-container {
            text-align: center;
            padding: 10px;
            border-top: 1px solid #ddd;
            background: #ffffff;
        }

        .logout-button {
            background-color: #dc3545;
            color: #ffffff;
            border: none;
            padding: 10px 20px;
            border-radius: 5px;
            cursor: pointer;
            font-size: 14px;
            text-decoration: none;
        }

        .logout-button:hover {
            background-color: #c82333;
        }
    </style>
</head>
<body>
    <div class="chat-container">
        <div class="chat-header">
            <span>Chat with <?= htmlspecialchars($chat_with ?: 'Select a user') ?></span>
            <form method="POST" class="chat-select-form">
                <select name="chat_with" class="chat-select" onchange="this.form.submit()">
                    <option value="" disabled selected>Change chat</option>
                    <?php foreach ($available_users as $user): ?>
                        <option value="<?= htmlspecialchars($user) ?>" <?= $chat_with === $user ? 'selected' : '' ?>>
                            <?= htmlspecialchars($user) ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </form>
        </div>

        <div class="chat-box" id="chat-box">
            <?php
            if ($chat_with && file_exists($chat_log_file)) {
                $chat_history = file($chat_log_file, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
                foreach ($chat_history as $line) {
                    echo "<div>" . htmlspecialchars($line) . "</div>";
                }
            } else {
                echo "<div>No messages yet.</div>";
            }
            ?>
        </div>

        <form method="POST" action="" class="message-form">
            <input type="text" name="message" placeholder="Type your message..." required autofocus>
            <button type="submit">Send</button>
        </form>

        <div class="logout-container">
            <a href="logout.php" class="logout-button">Logout</a>
        </div>
    </div>

    <script>
        // Auto-scroll to the bottom of the chat box
        const chatBox = document.getElementById('chat-box');
        chatBox.scrollTop = chatBox.scrollHeight;

        function loadMessages() {
            fetch('load_messages.php?chat_with=<?= urlencode($chat_with) ?>')
                .then(response => response.text())
                .then(data => {
                    chatBox.innerHTML = data;
                    chatBox.scrollTop = chatBox.scrollHeight;
                });
        }

        // Load messages every second
        setInterval(loadMessages, 1000);
        loadMessages();
    </script>
</body>
</html>
